==> chromium-8.0.552.40.tar.bz2: chromium-8.0.552.40/o3d/plugin/cross/main_thread_task_poster.cc <==
/*
 * Copyright 2009, Google Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include <npapi.h>
#include "npn_api.h"
#include "plugin/cross/main_thread_task_poster.h"

namespace o3d {

MainThreadTaskPoster::MainThreadTaskPoster(ServiceLocator* service_locator,
                                           NPP npp)
    : service_(service_locator, this),
      npp_(npp) {
}

MainThreadTaskPoster::~MainThreadTaskPoster() {
}

bool MainThreadTaskPoster::IsSupported() {
 return IsPluginThreadAsyncCallSupported();
}

void MainThreadTaskPoster::PostTask(Task* task) {
  DCHECK(IsSupported());
  NPN_PluginThreadAsyncCall(npp_, &MainThreadTaskPoster::RunTask, task);
}

void MainThreadTaskPoster::RunTask(void* data) {
  Task* task = static_cast<Task*>(data);
  task->Run();
  delete task;
}
}  // namespace o3d

==> chromium-10.0.648.204.tar.bz2: chromium-10.0.648.204/o3d/plugin/cross/main_thread_task_poster.cc <==
/*
 * Copyright 2009, Google Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include <npapi.h>
#include "npn_api.h"
#include "plugin/cross/main_thread_task_poster.h"

namespace o3d {

MainThreadTaskPoster::MainThreadTaskPoster(ServiceLocator* service_locator,
                                           NPP npp)
    : service_(service_locator, this),
      npp_(npp) {
}

MainThreadTaskPoster::~MainThreadTaskPoster() {
}

bool MainThreadTaskPoster::IsSupported() {
  return IsPluginThreadAsyncCallSupported(npp_);
}

void MainThreadTaskPoster::PostTask(Task* task) {
  DCHECK(IsSupported());
  NPN_PluginThreadAsyncCall(npp_, &MainThreadTaskPoster::RunTask, task);
}

void MainThreadTaskPoster::RunTask(void* data) {
  Task* task = static_cast<Task*>(data);
  task->Run();
  delete task;
}
}  // namespace o3d
